searchData={"content_type":"text/markdown","items":[{"doc":"Documentation for `Kujira`.","ref":"Kujira.html","title":"Kujira","type":"module"},{"doc":"Get transactions where the sender is `address`","ref":"Kujira.html#txs_by_sender/3","title":"Kujira.txs_by_sender/3","type":"function"},{"doc":"Kujira's on-chain Market Maker for FIN.","ref":"Kujira.Bow.html","title":"Kujira.Bow","type":"module"},{"doc":"Fetches the Leverage contract and its current config from the chain.\n\nConfig is very very rarely changed, if ever, and so this function is Memoized by default.\n\nManually clear with `Kujira.Bow.invalidate(:get_leverage, address)`","ref":"Kujira.Bow.html#get_leverage/2","title":"Kujira.Bow.get_leverage/2","type":"function"},{"doc":"Fetches an XYK algorithm pool and its current config from the chain.\n\nConfig is very very rarely changed, if ever, and so this function is Memoized by default.\n\nManually clear with `Kujira.Bow.invalidate(:get_pool_xyk, address)`","ref":"Kujira.Bow.html#get_pool_xyk/2","title":"Kujira.Bow.get_pool_xyk/2","type":"function"},{"doc":"Fetches all Leverage markets. This will only change when config changes or new markets are added.\nIt's Memoized, clearing every 24h.\n\nManually clear with `Kujira.Bow.invalidate(:list_leverage)`","ref":"Kujira.Bow.html#list_leverage/2","title":"Kujira.Bow.list_leverage/2","type":"function"},{"doc":"**WIP**\n\nLoads the Leverage Market into a format that Orca can consume for health reporting. Default Memoization to 10 mins\n\nThe liquidation price of a position is dependent on the algorithm of the BOW pool.\n\nEg: KUJI is at 2 USDC when a position is opened. The BOW pool is in a 1:2 ratio, and I deposit 100 KUJI and borrow 200 USDC.\nMy initial LTV is 0.5 - a total of $400 of LP tokens with $200 borrowed.\nSay the max LTV is 0.8, then liquidation can ocurr when the LP value decreases to 250 USDC.\nIn this instance, as the ratio of the pool should be the current price, there will be 125 USDC and X * 125 = 20000 so 160 KUJI where the price is now 0.78125\n\nThe liquidation price if KUJI is the borrowed asset is the same deviation in the opposite direction\nI deposit 200 USDC and borrow 100 KUJI\nMax LTV 0.8 liquidation can ocurr when LP value is 125 KUJI\nSo there'll be 62.5 KUJI and 62.5 * Y = 20000 so 320 USDC and the price is 5.12\n\nBlended liquidation price\nI deposit 100 USDC, 75 KUJI and borrow 100 USDC and 25 KUJI\nMax LTV 0.8 liquidation can ocurr when LP value is 125 KUJI\nSo there'll be 62.5 KUJI and 62.5 * Y = 20000 so 320 USDC and the price is 5.12\n\n\n\n\nManually clear with `Kujira.Bow.invalidate(:load_orca_market, market)`","ref":"Kujira.Bow.html#load_orca_market/3","title":"Kujira.Bow.load_orca_market/3","type":"function"},{"doc":"Loads the current pool status onto the pool\n\nIt's Memoized, clearing every 2 seconds.\n\nManually clear with `Kujira.Bow.invalidate(:load_pool, address)`","ref":"Kujira.Bow.html#load_pool/2","title":"Kujira.Bow.load_pool/2","type":"function"},{"doc":"A CDP contract that integrates BOW with GHOST, allowing LP tokens to be used as collateral when borrowing the underlying tokens\nthat make up the LP position.\n\nThis allows an LP-er to provide eg only the base asset of a pair, and borrow the stable quote-side of the position, in order to avoid having\nto sell any of their position in order to provide liquidity.","ref":"Kujira.Bow.Leverage.html","title":"Kujira.Bow.Leverage","type":"module"},{"doc":"* `:address` - The address of the contract\n\n* `:owner` - The owner of the contract\n\n* `:bow` - The BOW contract that the liquidity is deposited to\n\n* `:token_base` - The base Token of the LP pair\n\n* `:token_quote` - The quote Token of the LP pair\n\n* `:oracle_base` - The Oracle feed used to price the base token\n\n* `:oracle_quote` - The Oracle feed used to price the quote token\n\n* `:ghost_vault_base` - The GHOST Vault where the base token is borrowed from\n\n* `:ghost_vault_quote` - The GHOST Vault where the quote token is borrowed from\n\n* `:orca_queue_base` - The ORCA Queue where the base token is liquidated to repay the GHOST quote Vault\n\n* `:orca_queue_quote` - The ORCA Queue where the quote token is liquidated to repay the GHOST base Vault\n\n* `:max_ltv` - The maximum ratio of the value of borrowed tokens to value of LP tokens, above which a position can be liquidated\n\n* `:full_liquidation_threshold` - The position value below which a liquidation covers all outstanding debt\n\n* `:partial_liquidation_target` - The target LTV to be achieved when a position is partially liquidated\n\n* `:borrow_fee` - The percentage of borrowed assets that are sent to KUJI stakers as a fee","ref":"Kujira.Bow.Leverage.html#module-fields","title":"Fields - Kujira.Bow.Leverage","type":"module"},{"doc":"","ref":"Kujira.Bow.Leverage.html#from_config/2","title":"Kujira.Bow.Leverage.from_config/2","type":"function"},{"doc":"","ref":"Kujira.Bow.Leverage.html#t:t/0","title":"Kujira.Bow.Leverage.t/0","type":"type"},{"doc":"An individual position in a BOW Leverage contract","ref":"Kujira.Bow.Leverage.Position.html","title":"Kujira.Bow.Leverage.Position","type":"module"},{"doc":"The current deposit and borrow totals","ref":"Kujira.Bow.Leverage.Status.html","title":"Kujira.Bow.Leverage.Status","type":"module"},{"doc":"* `:deposited` - The amount of LP token deposited\n\n* `:borrowed_base` - The amount of the base token of the pair borrowed\n\n* `:borrowed_quote` - The amount of the quote token of the pair borrowed","ref":"Kujira.Bow.Leverage.Status.html#module-fields","title":"Fields - Kujira.Bow.Leverage.Status","type":"module"},{"doc":"","ref":"Kujira.Bow.Leverage.Status.html#from_query/1","title":"Kujira.Bow.Leverage.Status.from_query/1","type":"function"},{"doc":"","ref":"Kujira.Bow.Leverage.Status.html#t:t/0","title":"Kujira.Bow.Leverage.Status.t/0","type":"type"},{"doc":"A instance of the BOW LSD Market Making strategy.","ref":"Kujira.Bow.Lsd.html","title":"Kujira.Bow.Lsd","type":"module"},{"doc":"A instance of the BOW Stable Market Making strategy.","ref":"Kujira.Bow.Stable.html","title":"Kujira.Bow.Stable","type":"module"},{"doc":"The current status of deposits to an LP pool","ref":"Kujira.Bow.Status.html","title":"Kujira.Bow.Status","type":"module"},{"doc":"* `:base_amount` - The total amount of the base token owned by the pool\n\n* `:quote_amount` - The total amount of the quote token owned by the pool\n\n* `:lp_amount` - The total amount of LP tokens minted by the pool","ref":"Kujira.Bow.Status.html#module-fields","title":"Fields - Kujira.Bow.Status","type":"module"},{"doc":"","ref":"Kujira.Bow.Status.html#from_query/2","title":"Kujira.Bow.Status.from_query/2","type":"function"},{"doc":"","ref":"Kujira.Bow.Status.html#t:t/0","title":"Kujira.Bow.Status.t/0","type":"type"},{"doc":"A instance of the BOW XYK Market Making strategy.","ref":"Kujira.Bow.Xyk.html","title":"Kujira.Bow.Xyk","type":"module"},{"doc":"* `:address` - The address of the contract\n\n* `:owner` - The owner of the contract\n\n* `:fin_pair` - The FIN Pair that this pool market-makes for\n\n* `:token_lp` - The receipt token minted when deposits are made to the pool\n\n* `:token_base` - The base token of the FIN Pair\n\n* `:token_quote` - The quote token of the FIN Pair\n\n* `:decimal_delta` - Base decimals - Quote decimals. Used to assert correct price_precision\n\n* `:price_precision` - Maximum number of decimal places of the human price when submitting orders\n\n* `:intervals` - The space between orders placed by the contract\n\n* `:fee` - The premium calculated on top of the XY=K algorithm, used to size orders\n\n* `:status` - The current deposit status","ref":"Kujira.Bow.Xyk.html#module-fields","title":"Fields - Kujira.Bow.Xyk","type":"module"},{"doc":"","ref":"Kujira.Bow.Xyk.html#from_config/2","title":"Kujira.Bow.Xyk.from_config/2","type":"function"},{"doc":"","ref":"Kujira.Bow.Xyk.html#t:t/0","title":"Kujira.Bow.Xyk.t/0","type":"type"},{"doc":"Convenience methods for querying CosmWasm smart contracts on Kujira","ref":"Kujira.Contract.html","title":"Kujira.Contract","type":"module"},{"doc":"","ref":"Kujira.Contract.html#by_code/2","title":"Kujira.Contract.by_code/2","type":"function"},{"doc":"","ref":"Kujira.Contract.html#by_codes/2","title":"Kujira.Contract.by_codes/2","type":"function"},{"doc":"","ref":"Kujira.Contract.html#get/2","title":"Kujira.Contract.get/2","type":"function"},{"doc":"","ref":"Kujira.Contract.html#list/3","title":"Kujira.Contract.list/3","type":"function"},{"doc":"Queries the full, raw contract state at an address. Default 1h cache","ref":"Kujira.Contract.html#query_state_all/3","title":"Kujira.Contract.query_state_all/3","type":"function"},{"doc":"","ref":"Kujira.Contract.html#query_state_smart/3","title":"Kujira.Contract.query_state_smart/3","type":"function"},{"doc":"Streams the current contract state","ref":"Kujira.Contract.html#stream_state_all/2","title":"Kujira.Contract.stream_state_all/2","type":"function"},{"doc":"Kujira's 100% on-chain, central limit order book style decentralized token exchange.","ref":"Kujira.Fin.html","title":"Kujira.Fin","type":"module"},{"doc":"Fetches the Pair contract and its current config from the chain.\n\nConfig is very very rarely changed, if ever, and so this function is Memoized by default.\n\nManually clear with `Kujira.Fin.invalidate(:get_pair, address)`","ref":"Kujira.Fin.html#get_pair/2","title":"Kujira.Fin.get_pair/2","type":"function"},{"doc":"","ref":"Kujira.Fin.html#invalidate/1","title":"Kujira.Fin.invalidate/1","type":"function"},{"doc":"","ref":"Kujira.Fin.html#invalidate/2","title":"Kujira.Fin.invalidate/2","type":"function"},{"doc":"","ref":"Kujira.Fin.html#invalidate/3","title":"Kujira.Fin.invalidate/3","type":"function"},{"doc":"Fetches all Pairs. This will only change when config changes or new Pairs are added.\nIt's Memoized, clearing every 24h.\n\nManually clear with `Kujira.Fin.invalidate(:list_pairs)`","ref":"Kujira.Fin.html#list_pairs/2","title":"Kujira.Fin.list_pairs/2","type":"function"},{"doc":"Loads the current Book into the Pair. Default Memoization to ~ block time / 2 = 2s\n\nManually clear with `Kujira.Fin.invalidate(:load_pair, address)`","ref":"Kujira.Fin.html#load_pair/3","title":"Kujira.Fin.load_pair/3","type":"function"},{"doc":"The aggregate of all existing orders on the book","ref":"Kujira.Fin.Book.html","title":"Kujira.Fin.Book","type":"module"},{"doc":"* `:bids` - A list of bids, descending by price (ie the limit is at index 0)\n\n* `:asks` - A list of asks, ascending by price (ie the limit is at index 0)","ref":"Kujira.Fin.Book.html#module-fields","title":"Fields - Kujira.Fin.Book","type":"module"},{"doc":"","ref":"Kujira.Fin.Book.html#from_query/1","title":"Kujira.Fin.Book.from_query/1","type":"function"},{"doc":"","ref":"Kujira.Fin.Book.html#t:t/0","title":"Kujira.Fin.Book.t/0","type":"type"},{"doc":"A specific price point in the order book summary","ref":"Kujira.Fin.Book.Price.html","title":"Kujira.Fin.Book.Price","type":"module"},{"doc":"* `:price` - The bid or ask price\n\n* `:total` - The total amount offered at this price\n\n* `:side` - Which side of the book this order is on","ref":"Kujira.Fin.Book.Price.html#module-fields","title":"Fields - Kujira.Fin.Book.Price","type":"module"},{"doc":"","ref":"Kujira.Fin.Book.Price.html#from_query/2","title":"Kujira.Fin.Book.Price.from_query/2","type":"function"},{"doc":"","ref":"Kujira.Fin.Book.Price.html#t:side/0","title":"Kujira.Fin.Book.Price.side/0","type":"type"},{"doc":"","ref":"Kujira.Fin.Book.Price.html#t:t/0","title":"Kujira.Fin.Book.Price.t/0","type":"type"},{"doc":"An individual order placed on a Pair","ref":"Kujira.Fin.Order.html","title":"Kujira.Fin.Order","type":"module"},{"doc":"","ref":"Kujira.Fin.Order.html#t:t/0","title":"Kujira.Fin.Order.t/0","type":"type"},{"doc":"An individual exchange pair between a base token and a quote token.","ref":"Kujira.Fin.Pair.html","title":"Kujira.Fin.Pair","type":"module"},{"doc":"* `:address` - The address of the pair\n\n* `:owner` - The owner of the pair\n\n* `:token_base` - The base token of the Pair - typically the one that's being traded\n\n* `:token_quote` - The quote token of the Pair - typically a stablecoin\n\n* `:price_precision` - The maximum valid decimal places of the human price. Comparable to a tick size\n\n* `:decimal_delta` - Base decimals - Quote decimals. Allows conversion between \"human\" prices and \"actual\" prices with respect to base units of each token\n\n* `:is_bootstrapping` - A Pair is in Bootstrapping mode until manually launched, in order to prevent large amounts of slippage on new books\n\n* `:fee_taker` - The amount of a market swap that is sent to the fee collector\n\n* `:fee_maker` - The amount of a filled and claimed limit order that is sent to the fee collector\n\n* `:book` - An aggregate summary of all orders in the Pair's order book","ref":"Kujira.Fin.Pair.html#module-fields","title":"Fields - Kujira.Fin.Pair","type":"module"},{"doc":"","ref":"Kujira.Fin.Pair.html#from_config/2","title":"Kujira.Fin.Pair.from_config/2","type":"function"},{"doc":"","ref":"Kujira.Fin.Pair.html#t:t/0","title":"Kujira.Fin.Pair.t/0","type":"type"},{"doc":"An individual trade on an individual pair. For a market swap where orders at multiple price\npoints are consumed, the trade is aggregated across all orders at each price.","ref":"Kujira.Fin.Trade.html","title":"Kujira.Fin.Trade","type":"module"},{"doc":"* `:id` - A unique ID for the trade; `\"#{txhash}-#{idx}\"`\n\n* `:pair` - The pair the trade was executed on\n\n* `:price` - The price the trade was executed at\n\n* `:direction` - Whether the taker of the trade was a buyer or a seller\n\n* `:amount_base` - The amount of the base token traded\n\n* `:amount_quote` - The amount of the quote token traded\n\n* `:txhash` - The hash of the transaction the trade was executed in\n\n* `:height` - The chain height when the trade was executed\n\n* `:timestamp` - The timestamp of the trade\n\n* `:idx` - The index of the trade within the transaction it was executed in.","ref":"Kujira.Fin.Trade.html#module-fields","title":"Fields - Kujira.Fin.Trade","type":"module"},{"doc":"Extracts all trade events from a tx_response.\n\nN.B: Prior to height 6_549_066 (2022-12-26T10:15:13+00:00), the FIN contract did not emit the `type` event which classifies\nthe Trade as a buy or a sell, and trades will not be collected by this function","ref":"Kujira.Fin.Trade.html#from_tx_response/1","title":"Kujira.Fin.Trade.from_tx_response/1","type":"function"},{"doc":"","ref":"Kujira.Fin.Trade.html#t:direction/0","title":"Kujira.Fin.Trade.direction/0","type":"type"},{"doc":"","ref":"Kujira.Fin.Trade.html#t:t/0","title":"Kujira.Fin.Trade.t/0","type":"type"},{"doc":"Kujira's lending platform.\n\nIt has a vault-market architecture, where multiple Market can draw down from a single Vault. A Market must be whitelisted,\nas the repayment is guaranteed by its own execution logic, e.g. being over-collateralised and having a connection to Orca\nto liquidate collateral when needed","ref":"Kujira.Ghost.html","title":"Kujira.Ghost","type":"module"},{"doc":"Gets the total deposit value of an address in a Vault.\nUnder the hood, this queries the addresses balance of the receipt token, and adjusts it by the deposit_ratio\n\nManually clear with `Kujira.Ghost.invalidate(:get_deposit, vault, depositor)`","ref":"Kujira.Ghost.html#get_deposit/3","title":"Kujira.Ghost.get_deposit/3","type":"function"},{"doc":"Fetches the Market contract and its current config from the chain.\n\nConfig is very very rarely changed, if ever, and so this function is Memoized by default.\nManually clear with `Kujira.Ghost.invalidate(:get_market, address)`","ref":"Kujira.Ghost.html#get_market/2","title":"Kujira.Ghost.get_market/2","type":"function"},{"doc":"Fetches the Vault contract and its current config from the chain.\n\nConfig is very very rarely changed, if ever, and so this function is Memoized by default.\nManually clear with `Kujira.Ghost.invalidate(:get_vault, address)`","ref":"Kujira.Ghost.html#get_vault/2","title":"Kujira.Ghost.get_vault/2","type":"function"},{"doc":"","ref":"Kujira.Ghost.html#invalidate/1","title":"Kujira.Ghost.invalidate/1","type":"function"},{"doc":"","ref":"Kujira.Ghost.html#invalidate/2","title":"Kujira.Ghost.invalidate/2","type":"function"},{"doc":"","ref":"Kujira.Ghost.html#invalidate/3","title":"Kujira.Ghost.invalidate/3","type":"function"},{"doc":"Fetches all Markets. This will only change when config changes or new Markets are added.\nIt's Memoized, clearing every 24h.\n\nManually clear with `Kujira.Ghost.invalidate(:list_markets)`","ref":"Kujira.Ghost.html#list_markets/2","title":"Kujira.Ghost.list_markets/2","type":"function"},{"doc":"Fetches all Vaults. This will only change when config changes or new Vaults are added.\nIt's Memoized, clearing every 24h.\n\nManually clear with `Kujira.Ghost.invalidate(:list_vaults)`","ref":"Kujira.Ghost.html#list_vaults/2","title":"Kujira.Ghost.list_vaults/2","type":"function"},{"doc":"Loads the current Status into the Market. Default Memoization to ~ block time / 2 = 2s\n\nManually clear with `Kujira.Ghost.invalidate(:load_market, market)`","ref":"Kujira.Ghost.html#load_market/2","title":"Kujira.Ghost.load_market/2","type":"function"},{"doc":"Loads the Market into a format that Orca can consume for health reporting. Default Memoization to 10 mins\n\nManually clear with `Kujira.Ghost.invalidate(:load_orca_market, market)`","ref":"Kujira.Ghost.html#load_orca_market/3","title":"Kujira.Ghost.load_orca_market/3","type":"function"},{"doc":"Loads a Position by borrower address. Default Memoization to ~ block time / 2 = 2s\n\nManually clear with `Kujira.Ghost.invalidate(:load_position, market, borrower)`","ref":"Kujira.Ghost.html#load_position/3","title":"Kujira.Ghost.load_position/3","type":"function"},{"doc":"Loads the current Status into the Vault. Default Memoization to ~ block time / 2 = 2s\n\nManually clear with `Kujira.Ghost.invalidate(:load_vault, vault)`","ref":"Kujira.Ghost.html#load_vault/2","title":"Kujira.Ghost.load_vault/2","type":"function"},{"doc":"","ref":"Kujira.Ghost.html#load_vault_oracle_price/2","title":"Kujira.Ghost.load_vault_oracle_price/2","type":"function"},{"doc":"Creates a lazy stream for fetching all positions for a Market","ref":"Kujira.Ghost.html#stream_positions/3","title":"Kujira.Ghost.stream_positions/3","type":"function"},{"doc":"A Ghost market takes deposits of collateral_token, and allows borrowing of the vault.deposit_token, up to the maximum LTV as quoted by the oracle denoms","ref":"Kujira.Ghost.Market.html","title":"Kujira.Ghost.Market","type":"module"},{"doc":"* `:address` - The address of the market\n\n* `:owner` - The owner of the market\n\n* `:vault_address` - The address of Vault that the Market draws from\n\n* `:orca_address` - The address of the Orca Queue that is used to liquidate the collateral token\n\n* `:collateral_token` - The token used to back the loan\n\n* `:collateral_oracle_denom` - The denom string that is used to price the collateral token\n\n* `:max_ltv` - MAximum loan-to-value ratio of a position\n\n* `:full_liquidation_threshold` - The value of collateral (as priced by collateral oracle, 6dp), below which a position is 100% liquidated\n\n* `:partial_liquidation_target` - The target LTV when a position is partially liquidated\n\n* `:borrow_fee` - The amount of the borrowed asset retained as a fee when borrow amount is increased","ref":"Kujira.Ghost.Market.html#module-fields","title":"Fields - Kujira.Ghost.Market","type":"module"},{"doc":"","ref":"Kujira.Ghost.Market.html#from_config/2","title":"Kujira.Ghost.Market.from_config/2","type":"function"},{"doc":"","ref":"Kujira.Ghost.Market.html#t:t/0","title":"Kujira.Ghost.Market.t/0","type":"type"},{"doc":"The current deposit and borrow totals","ref":"Kujira.Ghost.Market.Status.html","title":"Kujira.Ghost.Market.Status","type":"module"},{"doc":"* `:deposited` - The amount of collateral_token deposited\n\n* `:borrowed` - The amount of the Vault deposit_token borrowed","ref":"Kujira.Ghost.Market.Status.html#module-fields","title":"Fields - Kujira.Ghost.Market.Status","type":"module"},{"doc":"","ref":"Kujira.Ghost.Market.Status.html#from_query/1","title":"Kujira.Ghost.Market.Status.from_query/1","type":"function"},{"doc":"","ref":"Kujira.Ghost.Market.Status.html#t:t/0","title":"Kujira.Ghost.Market.Status.t/0","type":"type"},{"doc":"An item representing the collateral deposit vs debt position of a particular address for a particular market","ref":"Kujira.Ghost.Position.html","title":"Kujira.Ghost.Position","type":"module"},{"doc":"* `:market` - The market where the position is held\n\n* `:holder` - The address that owns the position\n\n* `:collateral_amount` - The amount of collateral_token that has been deposited\n\n* `:debt_shares` - The amount of debt_token minted and owned by this position\n\n* `:debt_amount` - The resultant amount of debt owed, based on the `debt_ratio`","ref":"Kujira.Ghost.Position.html#module-fields","title":"Fields - Kujira.Ghost.Position","type":"module"},{"doc":"","ref":"Kujira.Ghost.Position.html#from_query/3","title":"Kujira.Ghost.Position.from_query/3","type":"function"},{"doc":"Returns all adjustments to positions found in the tx response","ref":"Kujira.Ghost.Position.html#from_tx_response/1","title":"Kujira.Ghost.Position.from_tx_response/1","type":"function"},{"doc":"The direction of the adjustment to the Position: collateral deposit, collateral withdrawal, debt borrow, debt repay\n\nTODO: Add :liquidation","ref":"Kujira.Ghost.Position.html#t:adjustment/0","title":"Kujira.Ghost.Position.adjustment/0","type":"type"},{"doc":"","ref":"Kujira.Ghost.Position.html#t:t/0","title":"Kujira.Ghost.Position.t/0","type":"type"},{"doc":"A central vault for deposits of a specific deposit_token, which is lent to the Vault's markets, and interest earned on deposits","ref":"Kujira.Ghost.Vault.html","title":"Kujira.Ghost.Vault","type":"module"},{"doc":"* `:address` - The address of the market\n\n* `:owner` - The owner of the market\n\n* `:deposit_token` - The token deposited into the vault to be lent\n\n* `:oracle_denom` - The denom string that is used to price the deposit token\n\n* `:receipt_token` - The token minted on deposit, that represents ownership of that deposit\n\n* `:debt_token` - The token minted and sent to a Market when borrowing, use as an accounting tool to accrue interest on debt\n\n* `:markets` - The whitelisted markets that are allowed to borrow from the Vault","ref":"Kujira.Ghost.Vault.html#module-fields","title":"Fields - Kujira.Ghost.Vault","type":"module"},{"doc":"","ref":"Kujira.Ghost.Vault.html#from_config/2","title":"Kujira.Ghost.Vault.from_config/2","type":"function"},{"doc":"","ref":"Kujira.Ghost.Vault.html#t:t/0","title":"Kujira.Ghost.Vault.t/0","type":"type"},{"doc":"The current deposit and borrow totals","ref":"Kujira.Ghost.Vault.Status.html","title":"Kujira.Ghost.Vault.Status","type":"module"},{"doc":"* `:deposited` - The amount of deposit_token deposited\n\n* `:borrowed` - The amount of the Vault deposit_token lent out\n\n* `:rate` - The current interest rate charged on lent tokens\n\n* `:deposit_ratio` - The ratio between deposit_token and receipt_token\n\n* `:debt_ratio` - The ratiop between the debt_token and the amount of deposit_token owed by the borrowing Market","ref":"Kujira.Ghost.Vault.Status.html#module-fields","title":"Fields - Kujira.Ghost.Vault.Status","type":"module"},{"doc":"","ref":"Kujira.Ghost.Vault.Status.html#from_query/1","title":"Kujira.Ghost.Vault.Status.from_query/1","type":"function"},{"doc":"Returns all adjustments to the Vault.Status contained in a tx_response","ref":"Kujira.Ghost.Vault.Status.html#from_tx_response/1","title":"Kujira.Ghost.Vault.Status.from_tx_response/1","type":"function"},{"doc":"The direction of the adjustment to the Vault Status: user deposit, user withdrawal, market borrow, market repay","ref":"Kujira.Ghost.Vault.Status.html#t:adjustment/0","title":"Kujira.Ghost.Vault.Status.adjustment/0","type":"type"},{"doc":"","ref":"Kujira.Ghost.Vault.Status.html#t:t/0","title":"Kujira.Ghost.Vault.Status.t/0","type":"type"},{"doc":"","ref":"Kujira.Node.html","title":"Kujira.Node","type":"module"},{"doc":"Stores a gRPC connection to chain core node","ref":"Kujira.Node.Grpc.html","title":"Kujira.Node.Grpc","type":"module"},{"doc":"","ref":"Kujira.Node.Websocket.html","title":"Kujira.Node.Websocket","type":"module"},{"doc":"Utility functions for querying the on-chain oracle","ref":"Kujira.Oracle.html","title":"Kujira.Oracle","type":"module"},{"doc":"","ref":"Kujira.Oracle.html#invalidate/1","title":"Kujira.Oracle.invalidate/1","type":"function"},{"doc":"","ref":"Kujira.Oracle.html#invalidate/2","title":"Kujira.Oracle.invalidate/2","type":"function"},{"doc":"Loads the price for a specfic price from the on-chain oracle. Default cache 200ms\n\nClear wth Kujira.Oracle.invalidate(:load_price, denom)","ref":"Kujira.Oracle.html#load_price/2","title":"Kujira.Oracle.load_price/2","type":"function"},{"doc":"Loads all prices from the on-chain oracle. Default cache 200ms\n\nClear wth Kujira.Oracle.invalidate(:load_prices)","ref":"Kujira.Oracle.html#load_prices/1","title":"Kujira.Oracle.load_prices/1","type":"function"},{"doc":"Methods for querying the Orca Liquidation Queues, and related data","ref":"Kujira.Orca.html","title":"Kujira.Orca","type":"module"},{"doc":"Fetches the Queue contract and its current config from the chain.\n\nConfig is very very rarely changed, if ever, and so this function is Memoized forever by default.\n\nManually clear with `Kujira.Orca.invalidate(:get_queue, address)`","ref":"Kujira.Orca.html#get_queue/2","title":"Kujira.Orca.get_queue/2","type":"function"},{"doc":"","ref":"Kujira.Orca.html#invalidate/1","title":"Kujira.Orca.invalidate/1","type":"function"},{"doc":"","ref":"Kujira.Orca.html#invalidate/2","title":"Kujira.Orca.invalidate/2","type":"function"},{"doc":"","ref":"Kujira.Orca.html#invalidate/3","title":"Kujira.Orca.invalidate/3","type":"function"},{"doc":"","ref":"Kujira.Orca.html#invalidate/4","title":"Kujira.Orca.invalidate/4","type":"function"},{"doc":"Fetches all Liquidation Queues. This will only change when config changes or new Queues are added.\nIt's Memoized, clearing every 24h.\n\nManually clear with `Kujira.Orca.invalidate(:list_queues)`","ref":"Kujira.Orca.html#list_queues/2","title":"Kujira.Orca.list_queues/2","type":"function"},{"doc":"Loads a bid for a specific Queue. Default Memoization to ~ block time / 2 = 2s\n\nManually clear with `Kujira.Orca.invalidate(:load_bid, queue, idx)`","ref":"Kujira.Orca.html#load_bid/3","title":"Kujira.Orca.load_bid/3","type":"function"},{"doc":"Loads a user's bids for a specific Queue. Default Memoization to ~ block time / 2 = 2s\n\nManually clear with `Kujira.Orca.invalidate(:load_bids, queue, address)`","ref":"Kujira.Orca.html#load_bids/4","title":"Kujira.Orca.load_bids/4","type":"function"},{"doc":"Loads the current contract state into the Queue; the totals of each bid pool. Default Memoization to ~ block time / 2 = 2s\n\nManually clear with `Kujira.Orca.invalidate(:load_queue, queue)`","ref":"Kujira.Orca.html#load_queue/2","title":"Kujira.Orca.load_queue/2","type":"function"},{"doc":"Creates a lazy stream for fetching all bids for a Queue","ref":"Kujira.Orca.html#stream_positions/2","title":"Kujira.Orca.stream_positions/2","type":"function"},{"doc":"A bid placed by a user to buy liquidated collateral at a specific discount from the market price","ref":"Kujira.Orca.Bid.html","title":"Kujira.Orca.Bid","type":"module"},{"doc":"* `:id` - The unique ID of the bid\n\n* `:bidder` - The address that submitted the bid\n\n* `:delegate` - An optional account that can activate the bid on behalf of the bidder\n\n* `:bid_amount` - The remaining amount of the bid_token\n\n* `:filled_amount` - The amount of collateral available for withdrawal\n\n* `:premium` - The bid discount on the market rate\n\n* `:activation_time` - When not nil, the bid must be activated at or after this time","ref":"Kujira.Orca.Bid.html#module-fields","title":"Fields - Kujira.Orca.Bid","type":"module"},{"doc":"","ref":"Kujira.Orca.Bid.html#from_query/2","title":"Kujira.Orca.Bid.from_query/2","type":"function"},{"doc":"Returns all new bids found in a specific transaction","ref":"Kujira.Orca.Bid.html#from_tx_response/2","title":"Kujira.Orca.Bid.from_tx_response/2","type":"function"},{"doc":"","ref":"Kujira.Orca.Bid.html#t:t/0","title":"Kujira.Orca.Bid.t/0","type":"type"},{"doc":"An individual liquidation, as seen by Orca. These can be duplicated as the liquidating market\nwill also have something that represents the liquidation, but these may be different.","ref":"Kujira.Orca.Liquidation.html","title":"Kujira.Orca.Liquidation","type":"module"},{"doc":"* `:txhash` - The hash of the transaction the liqdation ocurred in\n\n* `:height` - The block height that included the transaction\n\n* `:timestamp` - The timestamp of the block\n\n* `:queue_address` - The address of the liquidation queue that processed the liquidation\n\n* `:market_address` - The market that requested the liquidation\n\n* `:collateral_amount` - The amount of collateral liquidated by the market\n\n* `:bid_amount` - The amount of bid_token that was consumed during the liquidation\n\n* `:repay_amount` - The amount of bid_token that was returned to the liquidating market\n\n* `:fee_amount` - The amount of the bid_token that was retained as a fee","ref":"Kujira.Orca.Liquidation.html#module-fields","title":"Fields - Kujira.Orca.Liquidation","type":"module"},{"doc":"Returns all liquidations found in a specific transaction","ref":"Kujira.Orca.Liquidation.html#from_tx_response/1","title":"Kujira.Orca.Liquidation.from_tx_response/1","type":"function"},{"doc":"","ref":"Kujira.Orca.Liquidation.html#t:t/0","title":"Kujira.Orca.Liquidation.t/0","type":"type"},{"doc":"We define a Market, as far as Orca is concerned, in order to be able to standardise\nand aggregate the health of the various markets that any given liquidation queue can liquidate","ref":"Kujira.Orca.Market.html","title":"Kujira.Orca.Market","type":"module"},{"doc":"* `:address` - The address of the market\n\n* `:health` - A bucketed map of market health -\n  key: liquidation price,\n  value: total collateral between this (inclusive) and the previous liquidation price (exclusive)","ref":"Kujira.Orca.Market.html#module-fields","title":"Fields - Kujira.Orca.Market","type":"module"},{"doc":"","ref":"Kujira.Orca.Market.html#t:t/0","title":"Kujira.Orca.Market.t/0","type":"type"},{"doc":"A pool of bid tokens at a specific premium %, for a specific Queue","ref":"Kujira.Orca.Pool.html","title":"Kujira.Orca.Pool","type":"module"},{"doc":"* `:premium` - The premium \"charged\" above the current market rate (ie the discount that the collateral is bought for)\n\n* `:total` - The total amount of activated bid token in the pool","ref":"Kujira.Orca.Pool.html#module-fields","title":"Fields - Kujira.Orca.Pool","type":"module"},{"doc":"Calculates a new Pool from the config on the Queue","ref":"Kujira.Orca.Pool.html#calculate/2","title":"Kujira.Orca.Pool.calculate/2","type":"function"},{"doc":"","ref":"Kujira.Orca.Pool.html#load/2","title":"Kujira.Orca.Pool.load/2","type":"function"},{"doc":"","ref":"Kujira.Orca.Pool.html#t:t/0","title":"Kujira.Orca.Pool.t/0","type":"type"},{"doc":"An individual Orca Liquidation Queue","ref":"Kujira.Orca.Queue.html","title":"Kujira.Orca.Queue","type":"module"},{"doc":"* `:address` - The contract address\n\n* `:owner` - The account authorized to make changes to contract config\n\n* `:collateral_token` - The token that is being liquidated\n\n* `:bid_token` - The token that is used to buy the collateral\n\n* `:bid_pools` - The aggregate amounts of bids at each supported discount amount. The contract confug contains `max_slot` and `premium_rate_per_slot`, which define these pools\n\n* `:activation_threshold` - The total amount of bids, above which the activation_delay must pass before a bid can be activated. This is `bid_threshold` on the contract interfaace\n\n* `:activation_delay` - The time in seconds that must pass before a bid can be activated. This is `waiting_period` on the contract interface","ref":"Kujira.Orca.Queue.html#module-fields","title":"Fields - Kujira.Orca.Queue","type":"module"},{"doc":"","ref":"Kujira.Orca.Queue.html#from_config/2","title":"Kujira.Orca.Queue.from_config/2","type":"function"},{"doc":"Assigns the current state to the bd_pools from a direct contract query response","ref":"Kujira.Orca.Queue.html#load_pools/2","title":"Kujira.Orca.Queue.load_pools/2","type":"function"},{"doc":"Enumerates all bid pools based on contract config","ref":"Kujira.Orca.Queue.html#populate_pools/3","title":"Kujira.Orca.Queue.populate_pools/3","type":"function"},{"doc":"","ref":"Kujira.Orca.Queue.html#t:t/0","title":"Kujira.Orca.Queue.t/0","type":"type"},{"doc":"Metadata for tokens on the Kujira Blockchain","ref":"Kujira.Token.html","title":"Kujira.Token","type":"module"},{"doc":"","ref":"Kujira.Token.html#from_denom/1","title":"Kujira.Token.from_denom/1","type":"function"},{"doc":"","ref":"Kujira.Token.html#t:t/0","title":"Kujira.Token.t/0","type":"type"},{"doc":"Kujira's decentralized stablecoin\n\nUsers deposit collateral and mint USK up to the maximum LTV permitted by the individual market","ref":"Kujira.Usk.html","title":"Kujira.Usk","type":"module"},{"doc":"Fetches the Controller contract and its current config from the chain.\n\nConfig is very very rarely changed, if ever, and so this function is Memoized by default.\n\nManually clear with `Kujira.Usk.invalidate(:get_controller)`","ref":"Kujira.Usk.html#get_controller/1","title":"Kujira.Usk.get_controller/1","type":"function"},{"doc":"Fetches the Margin contract and its current config from the chain.\n\nConfig is very very rarely changed, if ever, and so this function is Memoized by default.\n\nManually clear with `Kujira.Usk.invalidate(:get_margin, address)`","ref":"Kujira.Usk.html#get_margin/2","title":"Kujira.Usk.get_margin/2","type":"function"},{"doc":"Fetches the Market contract and its current config from the chain.\n\nConfig is very very rarely changed, if ever, and so this function is Memoized by default.\nManually clear with `Memoize.invalidate(Kujira.Contract, :get, [{Market, address}])`","ref":"Kujira.Usk.html#get_market/2","title":"Kujira.Usk.get_market/2","type":"function"},{"doc":"","ref":"Kujira.Usk.html#invalidate/1","title":"Kujira.Usk.invalidate/1","type":"function"},{"doc":"","ref":"Kujira.Usk.html#invalidate/2","title":"Kujira.Usk.invalidate/2","type":"function"},{"doc":"","ref":"Kujira.Usk.html#invalidate/3","title":"Kujira.Usk.invalidate/3","type":"function"},{"doc":"Fetches all Margins. This will only change when config changes or new Margins are added.\nIt's Memoized, clearing every 24h.\n\nManually clear with `Kujira.Usk.invalidate(:list_margins)`","ref":"Kujira.Usk.html#list_margins/2","title":"Kujira.Usk.list_margins/2","type":"function"},{"doc":"Fetches all Markets. This will only change when config changes or new Markets are added.\nIt's Memoized, clearing every 24h.\n\nManually clear with `Memoize.invalidate(Kujira.Contract, :list, [Market, code_ids])`","ref":"Kujira.Usk.html#list_markets/2","title":"Kujira.Usk.list_markets/2","type":"function"},{"doc":"Loads the current Status into the Margin.market. Default Memoization to ~ block time / 2 = 2s\n\nManually clear with `Kujira.Usk.invalidate(:load_margin, margin)`","ref":"Kujira.Usk.html#load_margin/2","title":"Kujira.Usk.load_margin/2","type":"function"},{"doc":"Loads the current Status into the Market. efault Memoization to ~ block time / 2 = 2s\n\nManually clear with `Kujira.Usk.invalidate(:load_market, address)`","ref":"Kujira.Usk.html#load_market/2","title":"Kujira.Usk.load_market/2","type":"function"},{"doc":"Loads the Market into a format that Orca can consume for health reporting. Default Memoization to 10 mins\n\nCan be used for both a Ghost.Market and Ghost.Margin.market, as they both use the same underlying\nstate schema\n\nManually clear with `Kujira.Usk.invalidate(:load_orca_market, market)`","ref":"Kujira.Usk.html#load_orca_market/3","title":"Kujira.Usk.load_orca_market/3","type":"function"},{"doc":"Loads a Position by borrower address. Default Memoization to ~ block time / 2 = 2s\n\nManually clear with `Kujira.Usk.invalidate(:load_position, market, borrower)`","ref":"Kujira.Usk.html#load_position/3","title":"Kujira.Usk.load_position/3","type":"function"},{"doc":"Creates a lazy stream for fetching all positions for a Market","ref":"Kujira.Usk.html#stream_positions/2","title":"Kujira.Usk.stream_positions/2","type":"function"},{"doc":"A contract that owns the minting rights for USK, and whitelists individual contracts for USK minting","ref":"Kujira.Usk.Controller.html","title":"Kujira.Usk.Controller","type":"module"},{"doc":"* `:address` - The address of the contract\n\n* `:owner` - The owner of the contract\n\n* `:token` - The token that this contract is the admin for (USK)\n\n* `:permitted` - Addresses permitted to mint USK via the controller","ref":"Kujira.Usk.Controller.html#module-fields","title":"Fields - Kujira.Usk.Controller","type":"module"},{"doc":"","ref":"Kujira.Usk.Controller.html#from_query/2","title":"Kujira.Usk.Controller.from_query/2","type":"function"},{"doc":"","ref":"Kujira.Usk.Controller.html#t:t/0","title":"Kujira.Usk.Controller.t/0","type":"type"},{"doc":"A margin contract for USK \"wraps\" the basic Market contract, allowing minted USK to purchase collateral\nfrom FIN, before posting it as collateral to a regular position. It also allows a position holder to take\nprofits by minting more USK against an appreciating collateral asset, or repaying some of the USK debt to\ncover a falling collateral price","ref":"Kujira.Usk.Margin.html","title":"Kujira.Usk.Margin","type":"module"},{"doc":"* `:fin_pair` - The FIN pair that is used to buy and sell collateral\n\n* `:market` - The underlying config of the USK CDP market","ref":"Kujira.Usk.Margin.html#module-fields","title":"Fields - Kujira.Usk.Margin","type":"module"},{"doc":"","ref":"Kujira.Usk.Margin.html#from_query/2","title":"Kujira.Usk.Margin.from_query/2","type":"function"},{"doc":"","ref":"Kujira.Usk.Margin.html#t:t/0","title":"Kujira.Usk.Margin.t/0","type":"type"},{"doc":"A USK market taked deposits of collateral_token, and allows minting of USK, up to the maximum LTV as quoted by the oracle denoms","ref":"Kujira.Usk.Market.html","title":"Kujira.Usk.Market","type":"module"},{"doc":"* `:address` - The address of the market\n\n* `:owner` - The owner of the market\n\n* `:stable_token` - The token that is minted\n\n* `:stable_token_admin` - The admin address of the stable_token\n\n* `:orca_address` - The address of the Orca Queue that is used to liquidate the collateral token\n\n* `:collateral_token` - The token used to back the loan\n\n* `:collateral_oracle_denom` - The denom string that is used to price the collateral token\n\n* `:max_ltv` - MAximum loan-to-value ratio of a position\n\n* `:full_liquidation_threshold` - The value of collateral (as priced by collateral oracle, 6dp), below which a position is 100% liquidated\n\n* `:liquidation_ratio` - The amount of a position liquidated when a position is partially liquidated\n\n* `:mint_fee` - The amount of the borrowed asset retained as a fee when borrow amount is increased\n\n* `:interest_rate` - The interest rate charged. Charged on the amount minted, paid in the collateral_token\n\n* `:max_debt` - Tha maximum amount of stable_token","ref":"Kujira.Usk.Market.html#module-fields","title":"Fields - Kujira.Usk.Market","type":"module"},{"doc":"","ref":"Kujira.Usk.Market.html#from_config/2","title":"Kujira.Usk.Market.from_config/2","type":"function"},{"doc":"","ref":"Kujira.Usk.Market.html#t:t/0","title":"Kujira.Usk.Market.t/0","type":"type"},{"doc":"The current mint total","ref":"Kujira.Usk.Market.Status.html","title":"Kujira.Usk.Market.Status","type":"module"},{"doc":"* `:minted` - The amount of the stable_token minted","ref":"Kujira.Usk.Market.Status.html#module-fields","title":"Fields - Kujira.Usk.Market.Status","type":"module"},{"doc":"","ref":"Kujira.Usk.Market.Status.html#from_query/1","title":"Kujira.Usk.Market.Status.from_query/1","type":"function"},{"doc":"","ref":"Kujira.Usk.Market.Status.html#t:t/0","title":"Kujira.Usk.Market.Status.t/0","type":"type"},{"doc":"An item representing the collateral deposit vs debt position of a particular address for a particular market","ref":"Kujira.Usk.Position.html","title":"Kujira.Usk.Position","type":"module"},{"doc":"* `:market` - The market where the position is held\n\n* `:holder` - The address that owns the position\n\n* `:collateral_amount` - The amount of collateral_token that has been deposited\n\n* `:mint_amount` - The amount of USK minted and owed by this position\n\n* `:interest_amount` - The amount of USK owed in interest. This is ultimately deducted from the collateral during a collateral deposit, withdrawal, or liquidation\n\n* `:debt_amount` - The total amount of USK owed - mint_amount + interest_amount","ref":"Kujira.Usk.Position.html#module-fields","title":"Fields - Kujira.Usk.Position","type":"module"},{"doc":"","ref":"Kujira.Usk.Position.html#from_query/2","title":"Kujira.Usk.Position.from_query/2","type":"function"},{"doc":"Returns all adjustments to positions found in the tx response","ref":"Kujira.Usk.Position.html#from_tx_response/1","title":"Kujira.Usk.Position.from_tx_response/1","type":"function"},{"doc":"The direction of the adjustment to the Position: collateral deposit, collateral withdrawal, debt borrow (mint), debt repay (burn)\n\nTODO: Add :liquidation","ref":"Kujira.Usk.Position.html#t:adjustment/0","title":"Kujira.Usk.Position.adjustment/0","type":"type"},{"doc":"","ref":"Kujira.Usk.Position.html#t:t/0","title":"Kujira.Usk.Position.t/0","type":"type"},{"doc":"","ref":"Mix.Tasks.DumpTx.html","title":"mix dump_tx","type":"task"},{"doc":"","ref":"Mix.Tasks.DumpTx.html#run/1","title":"Mix.Tasks.DumpTx.run/1","type":"function"}]}